LiveActivityStartRequest class

Live Activity start request.

Inheritance

Constructors

LiveActivityStartRequest({required String attributesType, required LiveActivityContent content, required Map<String, Object?> attributes})
const

Properties

attributes Map<String, Object?>
final
attributesType String
finalinherited
content LiveActivityContent
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited